==> soliq_id-1.1.1.tar.gz: lib/src/data/repository_impl/soliq_id_repository_impl.dart <==
import 'package:injectable/injectable.dart';

import '../api/soliq_id_api.dart';
import '../model/request/account_info_request.dart';
import '../model/request/compare_face_request.dart';
import '../model/request/create_session_request.dart';
import '../model/request/process_request.dart';
import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';
import '../repository/soliq_id_repository.dart';

@Singleton(as: SoliqIdRepository)
class SoliqIdRepositoryImpl implements SoliqIdRepository {
  final SoliqIdApi _soliqIdApi;

  SoliqIdRepositoryImpl(this._soliqIdApi);

  @override
  Future<AccountInfoResponse> setAccountInfo({
    required String deviceId,
    required int projectId,
    required String deviceName,
    required String factoryName,
    required int osType,
    required int pinfl,
    required String osVersion,
    required String appVersion,
    required String firebaseId,
    required String lang,
  }) async {
    return await _soliqIdApi.getAccountInfo(AccountInfoRequest(
      device: Device(
        projectId: projectId,
        firebaseId: firebaseId,
        deviceId: deviceId,
        deviceName: deviceName,
        factoryName: factoryName,
        osVersion: osVersion,
        appVersion: appVersion,
        osType: osType,
      ),
      pinfl: pinfl,
    ));
  }

  @override
  Future<ProcessResponse> compareFace({
    required String deviceId,
    required int id,
    required int asked,
    required String processId,
    required String image,
  }) {
    return _soliqIdApi.faceCompare(
      CompareFaceRequest(
        deviceId: deviceId,
        processId: processId,
        id: id,
        asked: asked,
        image: image,
      ),
    );
  }

  @override
  Future<CreateSessionResponse> createSession({
    required String deviceId,
    required int projectId,
    required String deviceName,
    required String factoryName,
    required int osType,
    required int pinfl,
    required String osVersion,
    required String appVersion,
    required String firebaseId,
    required String lang,
    required String fio,
  }) {
    return _soliqIdApi.session(CreateSessionRequest(
        pinfl: pinfl,
        fio: fio,
        device: Device(
          projectId: projectId,
          firebaseId: firebaseId,
          deviceId: deviceId,
          deviceName: deviceName,
          factoryName: factoryName,
          osVersion: osVersion,
          appVersion: appVersion,
          osType: osType,
        )));
  }

  @override
  Future<ProcessResponse> setProcess({
    required String deviceId,
    required int id,
    required int asked,
    required String processId,
    required String date,
  }) {
    return _soliqIdApi.logsApi(ProcesseRequest(
      deviceId: deviceId,
      processId: processId,
      id: id,
      asked: asked,
      date: date,
    ));
  }


}

==> soliq_id-1.2.1.tar.gz: lib/src/data/repository_impl/soliq_id_repository_impl.dart <==
import 'package:injectable/injectable.dart';

import '../api/soliq_id_api.dart';
import '../model/request/account_info_request.dart';
import '../model/request/compare_face_request.dart';
import '../model/request/create_session_request.dart';
import '../model/request/process_request.dart';
import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';
import '../repository/soliq_id_repository.dart';

@Singleton(as: SoliqIdRepository, dependsOn:[SoliqIdApi])
class SoliqIdRepositoryImpl implements SoliqIdRepository {
  final SoliqIdApi _soliqIdApi;

  SoliqIdRepositoryImpl(this._soliqIdApi);

  @override
  Future<AccountInfoResponse> setAccountInfo({
    required String deviceId,
    required int projectId,
    required String deviceName,
    required String factoryName,
    required int osType,
    required int pinfl,
    required String osVersion,
    required String appVersion,
    required String firebaseId,
    required String lang,
  }) async {
    return await _soliqIdApi.getAccountInfo(AccountInfoRequest(
      device: Device(
        projectId: projectId,
        firebaseId: firebaseId,
        deviceId: deviceId,
        deviceName: deviceName,
        factoryName: factoryName,
        osVersion: osVersion,
        appVersion: appVersion,
        osType: osType,
      ),
      pinfl: pinfl,
    ));
  }

  @override
  Future<ProcessResponse> compareFace({
    required String deviceId,
    required int id,
    required int asked,
    required String processId,
    required String image,
  }) {
    return _soliqIdApi.faceCompare(
      CompareFaceRequest(
        deviceId: deviceId,
        processId: processId,
        id: id,
        asked: asked,
        image: image,
      ),
    );
  }

  @override
  Future<CreateSessionResponse> createSession({
    required String deviceId,
    required int projectId,
    required String deviceName,
    required String factoryName,
    required int osType,
    required int pinfl,
    required String osVersion,
    required String appVersion,
    required String firebaseId,
    required String lang,
    required String fio,
  }) {
    return _soliqIdApi.session(CreateSessionRequest(
        pinfl: pinfl,
        fio: fio,
        device: Device(
          projectId: projectId,
          firebaseId: firebaseId,
          deviceId: deviceId,
          deviceName: deviceName,
          factoryName: factoryName,
          osVersion: osVersion,
          appVersion: appVersion,
          osType: osType,
        )));
  }

  @override
  Future<ProcessResponse> setProcess({
    required String deviceId,
    required int id,
    required int asked,
    required String processId,
    required String date,
  }) {
    return _soliqIdApi.logsApi(ProcesseRequest(
      deviceId: deviceId,
      processId: processId,
      id: id,
      asked: asked,
      date: date,
    ));
  }


}
